@@ -1,8 +1,10 @@
 __title__ = 'libtmux'
 __package_name__ = 'libtmux'
-__version__ = '0.8.0'
+__version__ = '0.8.1'
 __description__ = 'scripting library / orm for tmux'
 __email__ = 'tony@git-pull.com'
 __author__ = 'Tony Narlock'
+__github__ = 'https://github.com/tmux-python/libtmux'
+__pypi__ = 'https://pypi.org/project/libtmux/'
 __license__ = 'MIT'
-__copyright__ = 'Copyright 2016-2018 Tony Narlock'
+__copyright__ = 'Copyright 2016- Tony Narlock'
